/***************************************************************************
 *   Copyright (C) 2004 by Diego 'Flameeyes' Petteno                       *
 *   dgp85@users.sourceforge.net                                           *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "digestfile.h"
#include "sfvfile.h"
#include "md5sumfile.h"

#include <qdir.h>

#include <kprogress.h>

namespace KDigest {

DigestFile::DigestFile(QObject *parent, const char *name)
 : QObject(parent, name)
{
}

DigestFile::~DigestFile()
{
	for( DigestEntries::iterator it = m_entries.begin(); it != m_entries.end(); it++ )
		delete *it;
}

/**
@brief Non-interactively check a digest file 
@param filename Filename of the digest file to check
@param flags Flags for the check @see NICflags
@return true if all the files are right, false if the file can't be found or some files are broken
*/
bool DigestFile::checkFile(DigestType dt, const QString &filename, uint8_t flags)
{
	QDir c = QDir::current();
	if ( ! c.exists(filename) )
	{
		nicOutput(
			tr("File %1 not found in current folder").arg(filename),
			QString::null,
			flags|nicError
			);
		return false;
	}
	
	QString completefilename = c.absFilePath(filename);
	// Ok we have the absolute filename of the digest file, now create the DigestFile instance
	
	DigestFile *df;
	switch(dt)
	{
		case dtSFV:
			df = new SFVfile(completefilename);
			break;
		case dtMD5SUM:
			df = new MD5SUMfile(completefilename);
			break;
	}
	
	KProgressDialog progress(
		NULL,
		"progress_dialog",
		tr("Digest File Checking"),
		tr("Checking listed files"),
		true
		);

	progress.setAllowCancel(false);	
	progress.progressBar()->setTotalSteps( df->entries().count() );
	progress.connect(df, SIGNAL(cycleCompleted(int)), progress.progressBar(), SLOT(setValue(int)));
	progress.show();
	
	QDir f(completefilename); f.cd("..");
	if ( df->testFile( f.path() ) )
	{
		nicOutput(
			tr("All the digested files has the right digest"),
			tr("Check passed"),
			flags
			);
		return true;
	} else {
		nicOutput(
			tr("Some, or all, of the digested files was not found or their digest differs from the given one"),
			tr("Check failed"),
			flags
			);
		return false;
	}

	if ( flags & nicFinalReport )
	{
		///@todo print or display the final report
	}
}

};
#include "digestfile.moc"
